#' Title
#'
#' @param n_x size of field in x direction
#' @param n_y size of field in y direction
#' @param autocorr = TRUE. Does spatial field have autocorrelation?
#' @param amplitude Magnitude of response values
#' @param range degree of spatial autocorrelation - distance at which points influence each other
#'
#' @return a data frame with coordinates and initial values that follow spatial autocorrelation structure
#' @export
#'
#' @examples
#'
#' field <- define_pattern_s(20, 20, 1, 4)
#' ggplot2::ggplot(field, ggplot2::aes(x = x, y = y, fill = value)) +
#' ggplot2::geom_raster()
#'
define_pattern_s <- function(n_x, n_y, autocorr = TRUE, amplitude = 1, range = 0){
  if(autocorr == TRUE){
    if(amplitude <= 0){
      cli::cli_abort("Amplitude must have a positive value")
    }
    if(range < 0){
      cli::cli_abort("Range must be zero (for no autocorrelation) or a positive value")
    }
    if(range == 0){
      cli::cli_inform("Spatial autocorrelation is switched on but range is set to zero. This will approximate no autocorrelation.")
      field <- define_pattern_s_exp(n_x, n_y, amplitude, range)
    } else {
      field <- define_pattern_s_exp(n_x, n_y, amplitude, range)
    }
  } else {
    field <- define_pattern_s_indy(n_x, n_y)
  }
  field
}
