#' define_pattern_s_exp
#'
#' @param n_x size in x dimension
#' @param n_y size in y dimension
#' @param amplitude magnitude of response values
#' @param range degree of spatial autocorrelation - distance at which points influence each other
#'
#' @return a data frame with coordinates and initial values that follow spatial autocorrelation structure
#' @export
#' @examples
#'
#' field <- define_pattern_s_exp(20, 20, 1, 4)
#' ggplot2::ggplot(field, ggplot2::aes(x = x, y = y, fill = value)) +
#' ggplot2::geom_raster()
#'
define_pattern_s_exp <- function(n_x, n_y, amplitude = 1, range){
  coord_df <- expand.grid("x" = 1:n_x, "y" = 1:n_y)
  field <- geoR::grf(n = n_x*n_y, grid = coord_df, # Uniformly fill grid
                     cov.model = "exponential", # Autocorrelation
                     cov.pars = c(amplitude,range), # sigmasqrd, rho
                     messages = FALSE) |>
    convert_grf_to_df()
  field
}
