#' Generate spatial field without spatial autocorrelation
#'
#' @param n_x size of field in x direction
#' @param n_y size of field in y direction
#'
#' @return data frame with coordinates and associated values
#' @export
#'
#' @examples
#'
#' field <- define_pattern_s_indy(10,10)
#' ggplot2::ggplot(field, ggplot2::aes(x = x, y = y, fill = value)) +
#' ggplot2::geom_raster()
#'
define_pattern_s_indy <- function(n_x, n_y){
  coord_df <- expand.grid("x" = 1:n_x, "y" = 1:n_y)
  field <- geoR::grf(n = n_x*n_y, grid = coord_df, # Uniformly fill grid
      cov.model = "pure.nugget", # No autocorrelation
      cov.pars = c(1,0),# sigmasqrd=1, range =0
      messages = FALSE) |>
  convert_grf_to_df()
  field
}
