#' Create time series of given length
#'
#' @param n_units the length of time in series in time_units
#' @param time_unit  unit length of time, one of 'day', 'week', 'month', or 'year'. Defaults to 'year' DEFAULT: "year"
#'
#' @return a dataframe with the columns `year`, `month`, `week`, `day_of_month`, `day_of_year`, `day_of_timeseries`
#'
#' @examples
#' set_timeline(5, "year")
#' # Can cope with slight misspelling
#' set_timeline(5, "years")
#' set_timeline(5, "YeArS")
#'
#' set_timeline(36, "month")
#'
#' @export
set_timeline <- function(n_units, time_unit = "year") {
  if(tolower(time_unit)=="years"){
    time_unit <- "year"
  }
  if(tolower(time_unit)=="months"){
    time_unit <- "month"
  }
  if(tolower(time_unit)=="weeks"){
    time_unit <- "week"
  }
  if(tolower(time_unit)=="days"){
    time_unit <- "day"
  }
  if(!tolower(time_unit) %in% c('day', 'week', 'month', 'year')){
    stop("Invalid time_unit. Please use one of 'day', 'week', 'month', or 'year'.")
  }
  start_date <- as.Date("2001/01/01") # arbitrary
  end_date <- seq.Date(start_date, length.out = 2,
                       by=paste(n_units, time_unit, sep = " "))[2]

  all_days <- lubridate::ymd(seq(start_date, end_date-1, by = "days"))
  all_days
  # date_df <- data.frame(
  #   # "date" = all_days, # uncomment for bug fixing
  #   # Remove idea of real date to avoid confusion, set first year to 1
  #   "year" = as.numeric(format(all_days, format = "%Y"))-2000,
  #   "quarter" = as.numeric(sprintf("%02i", (as.POSIXlt(all_days)$mon) %/% 3L + 1L)),
  #   "month" = as.numeric(format(all_days, format = "%m")),
  #   "week" = as.numeric(format(all_days, format = "%V")),
  #   "day_of_week" = as.numeric(format(all_days, format = "%u")),
  #   "day_of_month" = as.numeric(format(all_days, format = "%d")),
  #   "day_of_year" = as.numeric(format(all_days, format = "%j")),
  #   "day_of_timeseries" = as.numeric(julian(all_days, origin = (start_date-1))) # -1 makes start date=1
  # )
  # date_df
}
