## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", fig.height = 6, fig.width = 8
)

## ----setup--------------------------------------------------------------------
set.seed(100)
library(ascot)
library(ggplot2)
library(patchwork)

## ----truth--------------------------------------------------------------------
# Set study area spatial extent
xlim=20
ylim=20

spatial_field <- define_pattern_s(xlim, ylim, autocorr = TRUE, range = 5)

# Determine duration of time series
time_df <- set_timeline(2, "week")
# Set time series pattern
time_series <- define_pattern_t(time_df,weekly_amplitude = 2, weekly_noise = 1)

truth <- simulate_spacetime(temporal_pattern = time_series,
                            field = spatial_field,
                            pattern_adherence = 0)

## ----point random-------------------------------------------------------------
#random sampling
point_sample1 <- sample_area_pointily(field= truth, n_samples=10, sampling_error=0.1, regular = FALSE, balanced = FALSE)

p1<-ggplot(truth, aes(x = x, y = y, fill = value)) +
  geom_raster() +
  labs(fill = "Value", title = "Regular = FALSE, Balanced = FALSE") +
  xlab("X coordinates")+
  ylab("Y coordinates") +
  geom_point(data=point_sample1, aes(x=x,y=y)) + facet_wrap(~date)+
  coord_equal(expand=FALSE, ylim=c(0,ylim), xlim=c(0,xlim))+
  scale_fill_viridis_c()+
  theme_bw()

p1


## ----point balance------------------------------------------------------------
#balanced sampling
point_sample2 <- sample_area_pointily(truth, 10, 0.1, regular = FALSE, balanced = TRUE)

p2<-ggplot(truth, aes(x = x, y = y, fill = value)) +
  geom_raster() +
  labs(fill = "Value", title = "Regular = FALSE, Balanced = TRUE") +
  xlab("X coordinates")+
  ylab("Y coordinates") +
  geom_point(data=point_sample2, aes(x=x,y=y))+
  facet_wrap(~date)+
  coord_equal(expand=FALSE, ylim=c(0,ylim), xlim=c(0,xlim))+
  scale_fill_viridis_c()+
  theme_bw()

p2

## ----regular------------------------------------------------------------------
#regular sampling
point_sample3 <- sample_area_pointily(truth,10, 0.1, regular = TRUE, balanced = FALSE)

p3<-ggplot(truth, aes(x = x, y = y, fill = value)) +
  geom_raster() +
  labs(fill = "Value", title = "Regular = TRUE") +
  xlab("X coordinates")+
  ylab("Y coordinates") +
  geom_point(data=point_sample3, aes(x=x,y=y)) +
  coord_equal(expand=FALSE, ylim=c(0,ylim), xlim=c(0,xlim))+
  facet_wrap(~date)+
  scale_fill_viridis_c()+
  theme_bw()

p3

## ----area random--------------------------------------------------------------

#set x and y area extent
y_range=3
x_range=3

#regular false and balance false
area_sample1 <- sample_area_areally(field=truth, n_samples =4,x_range =  x_range,y_range = y_range, sampling_error = 0.1, regular = FALSE, balanced = FALSE)

a1<-ggplot(truth, aes(x = x, y = y, fill = value)) +
  geom_raster(alpha=0.8,hjust = 0, vjust = 0) +
  labs(fill = "Value", title = "Regular = FALSE, Balanced = FALSE") +
  xlab("X coordinates")+
  ylab("Y coordinates") +
  geom_rect(data=area_sample1, mapping=aes(xmin=x-x_range, xmax=x+x_range, ymin=y-y_range, ymax=y+y_range, fill=area_value), color="black")+
  geom_point(data=area_sample1, aes(x=x,y=y)) +
  coord_equal(expand=FALSE, ylim=c(0,ylim), xlim=c(0,xlim))+
    facet_wrap(~date)+
  scale_fill_viridis_c()+
  theme_bw()

a1

## ----area balance-------------------------------------------------------------
#regular false and balance true
area_sample2 <- sample_area_areally(field = truth, n_samples = 5,x_range = x_range,y_range = y_range, sampling_error = 0.1, regular = FALSE, balanced = TRUE)

a2<-ggplot(truth, aes(x = x, y = y, fill = value)) +
  geom_raster(alpha=0.8,hjust = 0, vjust = 0) +
  labs(fill = "Value", title = "Regular = FALSE, Balanced = TRUE") +
  xlab("X coordinates")+
  ylab("Y coordinates") +
  geom_rect(data=area_sample2, mapping=aes(xmin=x-x_range, xmax=x+x_range, ymin=y-y_range, ymax=y+y_range, fill=area_value), color="black") +
  geom_point(data=area_sample2, aes(x=x,y=y))+
  coord_equal(expand=FALSE, ylim=c(0,ylim), xlim=c(0,xlim))+
  facet_wrap(~date)+
  scale_fill_viridis_c()+
  theme_bw()

a2


## ----area regular-------------------------------------------------------------
#regular true
area_sample3 <- sample_area_areally(field = truth,n_samples = 10,x_range = x_range,y_range = y_range, sampling_error = 0.1, regular = TRUE, balanced = FALSE)

a3<-ggplot(truth, aes(x = x, y = y, fill = value)) +
 geom_raster(alpha=0.8,hjust = 0, vjust = 0) +
  labs(fill = "Value", title = "Regular = TRUE") +
  xlab("X coordinates")+
  ylab("Y coordinates") +
  geom_rect(data=area_sample3, mapping=aes(xmin=x-x_range, xmax=x+x_range, ymin=y-y_range, ymax=y+y_range, fill=area_value), color="black") +
  geom_point(data=area_sample3, aes(x=x,y=y)) +
  coord_equal(expand=FALSE, ylim=c(0,ylim), xlim=c(0,xlim))+
  facet_wrap(~date)+
  scale_fill_viridis_c()+
  theme_bw()

a3

