## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", fig.height = 6, fig.width = 8
)

## ----setup--------------------------------------------------------------------
library(ascot)
library(patchwork)
library(ggplot2)

## ----spatial------------------------------------------------------------------
# Generate fields with different number of points
field_20x20 <- define_pattern_s(n_x=20, n_y=20, autocorr = FALSE)
field_10x20 <- define_pattern_s(n_x=10, n_y=20, autocorr = FALSE) 

# create plots
p1<-ggplot(field_20x20, aes(x = x, y = y, fill = value)) +
  geom_raster() + 
  labs(fill = "Value", title = "20x20 grid") + 
  xlab("X coordinates")+
  ylab("Y coordinates") +
  scale_fill_viridis_c()+
  theme_bw()

p2<-ggplot(field_10x20, aes(x = x, y = y, fill = value)) +
   geom_raster() + 
  labs(fill = "Value", title = "10x20 grid") + 
  xlab("X coordinates")+
  ylab("Y coordinates") +
  scale_fill_viridis_c()+
  theme_bw()

p1+p2+coord_equal()


## ----autocorrelation----------------------------------------------------------
# Generate Field
no_autocorr <- define_pattern_s(n_x=20, n_y=20, autocorr = FALSE)
with_autocorr <- define_pattern_s(n_x=20, n_y=20, autocorr = TRUE, amplitude = 1, range = 10)

# Visualise
p1<-ggplot(no_autocorr, aes(x = x, y = y, fill = value)) +
  geom_raster() + 
  labs(fill = "Value", title = "Without autocorrelation") + 
  xlab("X coordinates")+
  ylab("Y coordinates") +
  scale_fill_viridis_c()+
  theme_bw()

p2<-ggplot(with_autocorr, aes(x = x, y = y, fill = value)) +
  geom_raster() + 
  labs(fill = "Value", title = "With autocorrelation") + 
  xlab("X coordinates")+
  ylab("Y coordinates") +
  scale_fill_viridis_c()+
  theme_bw()

p1+p2+coord_equal()


## ----space-time---------------------------------------------------------------
spatial_field <- define_pattern_s(n_x=20, n_y=20, autocorr = TRUE,range = 2, amplitude = 1)

# Determine duration of time series
time_df <- set_timeline(2, "weeks")

# Set time series pattern
time_series <- define_pattern_t(time_df,weekly_amplitude = 2, weekly_noise = 1)

#Simulate spatio-temporal data
truth <- simulate_spacetime(temporal_pattern = time_series,
                            field = spatial_field,
                            pattern_adherence = 0)

#Plot the truth data
ggplot(truth, aes(x = x, y = y, fill = value)) +
  geom_raster(hjust = 0, vjust = 0) +
  labs(fill = "Value") +
  xlab("X coordinates")+
  ylab("Y coordinates")+
  coord_equal(expand=FALSE)+
  scale_fill_viridis_c()+
  facet_wrap(~date)+
  theme_bw()

## ----pattern0, fig.cap="Timeseries of the data generated with pattern_adherence = 0. Each line correspond to one point in space over time."----
spatial_field <- define_pattern_s(n_x=20, n_y=20, autocorr = TRUE,range = 2, amplitude = 1)

# Determine duration of time series
time_df <- set_timeline(2, "weeks")

# Set time series pattern
time_series <- define_pattern_t(time_df,weekly_amplitude = 2, weekly_noise = 1)

#Simulate spatio-temporal data
truth <- simulate_spacetime(temporal_pattern = time_series,
                            field = spatial_field,
                            pattern_adherence = 0)

 ggplot(truth, aes(x=date, y=value, group=paste0(x,"-",y)))+
        geom_point()+
        geom_path()+
        theme_bw()


## ----pattern10, fig.cap="Timeseries of the data generated with pattern_adherence = 2. Each line correspond to one point in space over time."----
spatial_field <- define_pattern_s(n_x=20, n_y=20, autocorr = TRUE,range = 2, amplitude = 1)

# Determine duration of time series
time_df <- set_timeline(2, "weeks")

# Set time series pattern
time_series <- define_pattern_t(time_df,weekly_amplitude = 2, weekly_noise = 1)

#Simulate spatio-temporal data
truth <- simulate_spacetime(temporal_pattern = time_series,
                            field = spatial_field,
                            pattern_adherence = 2)

 ggplot(truth, aes(x=date, y=value, group=paste0(x,"-",y)))+
        geom_point()+
        geom_path()+
        theme_bw()


