## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",fig.height = 6, fig.width = 8
)

## ----setup--------------------------------------------------------------------
library(ascot)
library(patchwork)
library(ggplot2)

## ----timeline, echo=TRUE------------------------------------------------------
# Determine duration of time series
time_df <- set_timeline(2, "years")
head(time_df)

## ----time-pattern-------------------------------------------------------------
# Create a time series   
weekly_time<-set_timeline(2, "month")

# Set week pattern without noise
weekly_timeseries_nonoise <- define_pattern_t(weekly_time,
                                weekly_amplitude = 1,
                                weekly_noise = 0,
                                seasonal_amplitude = 0,
                                seasonal_noise = 0,
                                annual_amplitude = 0,
                                annual_noise = 0)
weekly_timeseries_nonoise$label<-as.factor("Without noise")

# Set week pattern with noise  
weekly_timeseries_noise <- define_pattern_t(weekly_time,
                                weekly_amplitude = 1,
                                weekly_noise = 2,
                                seasonal_amplitude = 0,
                                seasonal_noise = 0,
                                annual_amplitude = 0,
                                annual_noise = 0)
weekly_timeseries_noise$label<-as.factor("With noise")

#Bind weekly patterns (with and without noise) datasets into single data frame
week_timeseries<-rbind(weekly_timeseries_nonoise, weekly_timeseries_noise)

# Create a time series   
season_time<-set_timeline(9, "month")

# Set seasonally pattern without noise 
season_timeseries_nonoise <- define_pattern_t(season_time,
                                weekly_amplitude = 0,
                                weekly_noise = 0,
                                seasonal_amplitude = 1,
                                seasonal_noise = 0,
                                annual_amplitude = 0,
                                annual_noise = 0)
season_timeseries_nonoise$label<-as.factor("Without noise")

# Set seasonally pattern with noise 
season_timeseries_noise <- define_pattern_t(season_time,
                                weekly_amplitude = 0,
                                weekly_noise = 0,
                                seasonal_amplitude = 1,
                                seasonal_noise = 2,
                                annual_amplitude = 0,
                                annual_noise = 0)
season_timeseries_noise$label<-as.factor("With noise")

#Bind seasonally patterns (with and without noise) datasets into single data frame
season_timeseries<-rbind(season_timeseries_nonoise, season_timeseries_noise)


# Set annual pattern without noise 
annual_timeseries_nonoise <- define_pattern_t(time_df,
                                weekly_amplitude = 0,
                                weekly_noise = 0,
                                seasonal_amplitude = 0,
                                seasonal_noise = 0,
                                annual_amplitude = 1,
                                annual_noise = 0)
annual_timeseries_nonoise$label<-as.factor("Without noise")

# Set annual pattern with noise 
annual_timeseries_noise <- define_pattern_t(time_df,
                                weekly_amplitude = 0,
                                weekly_noise = 0,
                                seasonal_amplitude = 0,
                                seasonal_noise = 0,
                                annual_amplitude = 1,
                                annual_noise = 2)
annual_timeseries_noise$label<-as.factor("With noise")

#Bind annual patterns (with and without noise) datasets into single data frame
annual_timeseries<-rbind(annual_timeseries_nonoise, annual_timeseries_noise)

# Create plots
week_plot<-ggplot(week_timeseries, aes(x = date, y = pattern, color=label)) +
  geom_path()+
  geom_point() +
  theme_bw()+
  labs(color="", title ="Weekly pattern", x="Date", y="Value")+
  scale_color_manual(values=c("black", alpha("grey",0.5))) 

season_plot<-ggplot(season_timeseries, aes(x = date, y = pattern, color=label)) +
  geom_path()+
  geom_point() +
  theme_bw()+
  labs(color="", title="seasonally pattern", x="Date", y="Value")+ 
  scale_color_manual(values=c("black", alpha("grey",0.5))) 

annual_plot<-ggplot(annual_timeseries, aes(x = date, y = pattern, color=label)) +
  geom_path()+
  geom_point() +
  theme_bw() +
  labs(color="", title="Annual pattern", x="Date", y="Value")+ 
  scale_color_manual(values=c("black", alpha("grey",0.5))) 

week_plot/season_plot/annual_plot + plot_layout(guides = "collect")

## ----combined-pattern---------------------------------------------------------
# Set time series  
timeseries<-set_timeline(6, "month")

# Set time series pattern without noise 
timeseries_nonoise <- define_pattern_t(timeseries,
                                weekly_amplitude = 2,
                                weekly_noise = 0,
                                seasonal_amplitude = 1,
                                seasonal_noise = 0,
                                annual_amplitude = 0,
                                annual_noise = 0)
timeseries_nonoise$label<-as.factor("Without noise")

# Set time series pattern with noise 
timeseries_noise <- define_pattern_t(timeseries,
                                weekly_amplitude = 2,
                                weekly_noise = 1,
                                seasonal_amplitude = 1,
                                seasonal_noise = 1,
                                annual_amplitude = 0,
                                annual_noise = 0)

timeseries_noise$label<-as.factor("With noise")

timeseries_combined<-rbind(timeseries_nonoise, timeseries_noise)

ggplot(timeseries_combined, aes(x = date, y = pattern, color=label)) +
  geom_path()+
  geom_point() +
  theme_bw() +
  labs(color="", x="Date", y="Value")+ 
  scale_color_manual(values=c("black", alpha("grey",0.5))) 

