# library(ascot)
library(dplyr)
library(ggplot2)
library(mgcv)
library(mgcViz)

load_all()
# Simulate Truth
time_df <- set_timeline(2, "year")
time_series <- define_pattern_t(time_df,
                                annual_amplitude = 1,
                                annual_noise = 0)

spatial_field <- define_pattern_s(20,20, autocorr = TRUE, range = 5)
truth <- simulate_spacetime(temporal_pattern = time_series,
                                 field = spatial_field,
                                 pattern_adherence = 0)

ggplot2::ggplot(truth %>% filter(date %in% sample(unique(truth$date), 9)),
                ggplot2::aes(x = x, y = y, fill = value)) +
  ggplot2::geom_raster() +
  ggplot2::facet_wrap(~date) +
  labs(title = "Random Selection of Dates in Time Series")

truth$loc_id <- paste(truth$x, truth$y, sep = "_")


ggplot2::ggplot(truth %>% filter(loc_id %in% sample(unique(truth$loc_id), 3)),
                                      ggplot2::aes(x = date, y = value,
                                                   colour = interaction(x,y))) +
  ggplot2::geom_line() +
  ggplot2::theme(legend.position = "none") +
  labs(title = "Random Selection of Locations in Field")


# Two sampling strategies
ds_reg <- sample_area_pointily(truth, n_samples = 25, sampling_error = 0.1,
                               regular = TRUE)
ds_bal <- sample_area_pointily(truth, n_samples = 25, sampling_error = 1,
                               regular = FALSE,
                               balanced = FALSE)
# Add family column
ds_reg$fam <- 1
ds_bal$fam <- 2

# Combine
dat <- rbind(ds_reg, ds_bal)

# Make response variable and family a list
dat$resp <- cbind(dat$point_sample, dat$fam)
dat$fam_factor  <- as.factor(dat$fam)
# # gfam works
# fit_gfam <- gam(resp ~ s(julian(date)), dat = dat,
#            family = gfam(list(gaussian, gaussian)), method = "REML")
# gam.check(fit_gfam)
# print(plot(getViz(fit_gfam), allTerms = T), pages = 1)
#
# # smooth works (with a decent sample size)
# fit_hgam <- gam(point_sample ~ s(julian(date)) +
#                   s(julian(date), fam_factor, bs = "fs"),
#                 dat = dat,
#            family = gaussian, method = "REML")
# gam.check(fit_hgam)
# print(plot(getViz(fit_hgam), allTerms = T), pages = 1)

# combo - note that there isn't a clear connection between fam and resp[,2]
str(dat)
fit_gfhbam <- bam(resp ~ s(julian(date)) +
                    s(julian(date), fam_factor, bs = "fs"), dat = dat,
                  family = gfam(list(gaussian, gaussian)),
                  # select = TRUE,
                  method = "fREML",
                  select = TRUE,
                  discrete = TRUE)
gam.check(fit_gfhbam)
print(plot(getViz(fit_gfhgam), allTerms = TRUE), pages = 1)

predict(fit_gfhbam)


fit_gfhgam_fs <- bam(resp ~ s(julian(date)) +
                       te(x, y, julian(date)) +
                       te(x, y, julian(date), fam_factor, bs = "fs"), dat = dat,
                  family = gfam(list(gaussian, gaussian)), method = "fREML",
                  discrete = TRUE,
                  select = TRUE)

gam.check(fit_gfhgam_fs)
print(plot(getViz(fit_gfhgam_fs), allTerms = TRUE), pages = 1)
summary(fit_gfhgam_fs)

dat$pred_value <- predict(fit_gfhgam_fs, newdata = dat)

ggplot(dat %>% filter(loc_id %in% sample(unique(dat$loc_id), 9)),
       aes(x = date, y = pred_value, colour = fam)) +
  geom_point() +
  facet_wrap(loc_id)
